@@ -17,7 +17,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <config.h>
+#include "config.h"
 
 #include "empathy-bad-password-dialog.h"
 
@@ -25,7 +25,6 @@
 
 #define DEBUG_FLAG EMPATHY_DEBUG_SASL
 #include <libempathy/empathy-debug.h>
-#include <libempathy/empathy-utils.h>
 
 G_DEFINE_TYPE (EmpathyBadPasswordDialog, empathy_bad_password_dialog,
     EMPATHY_TYPE_BASE_PASSWORD_DIALOG)
