@@ -21,8 +21,6 @@
 #ifndef __EMPATHY_CALL_UTILS_H__
 #define __EMPATHY_CALL_UTILS_H__
 
-#include <gst/gst.h>
-
 G_BEGIN_DECLS
 
 /* Calls */
@@ -36,9 +34,6 @@ GHashTable * empathy_call_create_call_request (const gchar *contact,
     gboolean initial_audio,
     gboolean initial_video);
 
-void empathy_call_set_stream_properties (GstElement *element,
-    gboolean echo_cancellation);
-
 TpSendingState empathy_call_channel_get_video_state (TpCallChannel *self);
 void empathy_call_channel_send_video (TpCallChannel *self,
     gboolean send);
