@@ -17,14 +17,10 @@
  * Authors: Guillaume Desmottes <guillaume.desmottes@collabora.co.uk>
  */
 
-#include <config.h>
-#include <string.h>
+#include "config.h"
 
-#include <libnotify/notification.h>
 #include <libnotify/notify.h>
 
-#include <telepathy-glib/telepathy-glib.h>
-
 #include <libempathy/empathy-gsettings.h>
 #include <libempathy/empathy-utils.h>
 
