@@ -25,6 +25,8 @@
 
 #include <libempathy/empathy-contact.h>
 
+#include <libnotify/notification.h>
+
 G_BEGIN_DECLS
 
 #define EMPATHY_NOTIFY_MANAGER_CAP_ACTIONS             "actions"
@@ -37,6 +39,7 @@ G_BEGIN_DECLS
 #define EMPATHY_NOTIFY_MANAGER_CAP_ICON_STATIC         "icon-static"
 #define EMPATHY_NOTIFY_MANAGER_CAP_IMAGE_SVG_XML       "image/svg+xml"
 #define EMPATHY_NOTIFY_MANAGER_CAP_SOUND                "sound"
+#define EMPATHY_NOTIFY_MANAGER_CAP_DESKTOP_ENTRY       "desktop-entry"
 /* notify-osd specific */
 #define EMPATHY_NOTIFY_MANAGER_CAP_X_CANONICAL_APPEND              "x-canonical-append"
 #define EMPATHY_NOTIFY_MANAGER_CAP_X_CANONICAL_PRIVATE_ICON_ONLY   "x-canonical-private-icon-only"
@@ -104,6 +107,11 @@ GdkPixbuf * empathy_notify_manager_get_pixbuf_for_notification (
     EmpathyContact *contact,
     const char *icon_name);
 
+NotifyNotification * empathy_notify_manager_create_notification (
+    const gchar *summary,
+    const char *body,
+    const gchar *icon);
+
 G_END_DECLS
 
 #endif /* __EMPATHY_NOTIFY_MANAGER_H__ */
