@@ -23,15 +23,9 @@
 
 #include "config.h"
 
-#include <string.h>
-#include <sys/types.h>
 #include <sys/stat.h>
 
-#include <libxml/parser.h>
-#include <libxml/tree.h>
-
 #include "empathy-client-factory.h"
-#include "empathy-tp-chat.h"
 #include "empathy-chatroom-manager.h"
 #include "empathy-utils.h"
 
