@@ -19,9 +19,7 @@
  * Thanks guys!
  */
 
-#include <config.h>
-
-#include <gtk/gtk.h>
+#include "config.h"
 
 #include "empathy-mic-menu.h"
 #include "empathy-mic-monitor.h"
